@@ -7,7 +7,8 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  GraphMatch
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
+--                 2011, 2012, 2016 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -83,7 +84,7 @@ instance (Label lb, Show lv) => Show (GenLabelEntry lb lv) where
 instance (Label lb, Eq lv) => Eq (GenLabelEntry lb lv) where
     (LabelEntry k1 v1) == (LabelEntry k2 v2) = (k1,v1) == (k2,v2)
 
-instance (Label lb, Show lv, Ord lv) => Ord (GenLabelEntry lb lv) where
+instance (Label lb, Ord lv) => Ord (GenLabelEntry lb lv) where
     (LabelEntry lb1 lv1) `compare` (LabelEntry lb2 lv2) =
         (lb1, lv1) `compare` (lb2, lv2)
 
