@@ -8,7 +8,7 @@
 -- |
 --  Module      :  GraphMem
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012, 2014 Douglas Burke
+--                 2011, 2012, 2014, 2016 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -47,7 +47,7 @@ import qualified Data.Set as S
 
 data GraphMem lb = GraphMem { arcs :: ArcSet lb }
 
-instance (Label lb) => LDGraph GraphMem lb where
+instance LDGraph GraphMem lb where
     emptyGraph   = GraphMem S.empty
     getArcs      = arcs
     setArcs g as = g { arcs=as }
