@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
 
 --------------------------------------------------------------------------------
@@ -5,12 +6,12 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  Integer
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2014 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
 --  Stability   :  experimental
---  Portability :  OverloadedStrings
+--  Portability :  CPP, OverloadedStrings
 --
 --  This module defines the structures used to represent and
 --  manipulate RDF @xsd:integer@ datatyped literals.
@@ -61,10 +62,13 @@ import Swish.RDF.Vocabulary
     , namespaceXsdType
     )
 
-import Data.Monoid(Monoid(..))
 import Control.Monad (liftM)
 import Data.Maybe (maybeToList)
 
+#if (!defined(__GLASGOW_HASKELL__)) || (__GLASGOW_HASKELL__ < 710)
+import Data.Monoid (Monoid(..))
+#endif
+
 import qualified Data.Text.Lazy.Builder as B
 
 ------------------------------------------------------------
