@@ -7,7 +7,7 @@
 -- |
 --  Module      :  Internal
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012, 2013, 2014 Douglas Burke
+--                 2011, 2012, 2013, 2014, 2016 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -245,7 +245,7 @@ processArcs gr =
 
 newtype SortedArcs lb = SA [Arc lb]
 
-sortArcs :: (Ord lb) => ArcSet lb -> SortedArcs lb
+sortArcs :: ArcSet lb -> SortedArcs lb
 sortArcs = SA . S.toAscList
 
 --  Rearrange a list of arcs into a tree of pairs which group together
