@@ -6,7 +6,7 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  RDFGraphTest
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2014 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2014, 2017 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -519,7 +519,11 @@ Valid values for xsd:integer include -123456789012345678901234567890, 2147483647
   ]
   
 utc1, utc2 :: UTCTime
+#if MIN_VERSION_time(1,6,0)
+utc1 = fromJust (buildTime defaultTimeLocale [])
+#else
 utc1 = buildTime defaultTimeLocale []
+#endif
 utc2 =
   let dNum = fromGregorian 2011 2 28
       tDiff = (23.0 - 3.0) * 3600.0 + 4.0 * 60.0 + 2.304 
